# [1.2.0](https://github.com/eieste/tfutility/compare/v1.1.1...v1.2.0) (2024-12-12)


### Bug Fixes

* add tests ([da45eaa](https://github.com/eieste/tfutility/commit/da45eaa894d4e923a8199fbbd9713dc51f39fd09))
* update docs ([67fae43](https://github.com/eieste/tfutility/commit/67fae43d96cf68f93f143cb8d6dad284b951e081))


### Features

* Many fixes and Refactors. Still in Initial Development ([#24](https://github.com/eieste/tfutility/issues/24)) ([6ddfaad](https://github.com/eieste/tfutility/commit/6ddfaad24e739f85366c00b4d6ce553ec42bba32))

# TF-Utils Change History

## 0.0.1

Initial release.
